{% extends "base.html" %}

{% block content %}
  <div class="container">
    <div class="row">
      <div class="col-md-12 home-bio">
        <p>Hi, I'm {{ author }}.</p>
      </div>
    </div>
  </div>
{% endblock %}
