{% extends "base.html" %}

{% block title %} &bull; blog{% endblock title %}

{% block content %}
  <div class="container">
    <p class="lead">{{ title }}</p>

    <table class="table table-responsive">
      {% for post in posts %}
        <tr>
          <td id="pubdate">{{ post['shortdate'] }}</td>
          <td>
            <a href="/{{ post.link }}">{{ post.title }}</a><br>
            {% for tag in post.tags %}
              <a href="/tag/{{ tag }}/" class="text-muted">#{{ tag }}</a>&nbsp;
            {% endfor %}
          </td>
        </tr>
      {% endfor %}
    </table>
  </div>
{% endblock %}
