<!DOCTYPE html>
<html lang="en">
  <head>
    <meta charset="utf-8">
    <title>{{ sitename }}{% block title %}{% endblock title %}</title>
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <link href="/feed.xml" rel="alternate" type="application/rss+xml" title="{{ sitename }}">
    <meta property="og:site_name" content="{{ sitename }}">
    {% block meta %}
      <meta property="og:title" content="{{ sitename }}">
      <meta property="og:type" content="website">
      <meta property="og:url" content="{{ rooturl }}{{ link }}">
    {% endblock %}
    <meta property="og:image" content="{{ rooturl }}static/img/{{ logo }}">
    <link rel="stylesheet" href="/static/css/lib/bootstrap.min.css">
    <link rel="stylesheet" href="/static/css/lib/bootstrap-theme.min.css">
    <link rel="stylesheet" href="/static/css/app.css">
    {% block css %}{% endblock %}
    <link rel="shortcut icon" href="/favicon.ico">
  </head>

  <body>
    <div id="wrapper">

      <div class="container">
        <div class="row">
          <div class="col-md-12 text-center">
            <p class="avatar">
              <a href="/">
                <img src="/static/img/{{ logo }}" alt="{{ author }}" class="avatar img-circle" />
              </a>
            </p>
            <h3>
              <a href="/index.html">About</a> &bull;
              <a href="/blog.html">Blog</a> &bull;
              <a href="/feed.xml" target="_blank">Feed</a>
            </h3>
          </div>
        </div>
      </div>

      {% block content %}{% endblock content %}

    </div>

    <div id="footer">
      <div class="container">
        powered by <a href="https://github.com/comzeradd/monopati" target="_blank">monopati</a> &bull;
        {{ license }}
      </div>
    </div>

    <script src="/static/js/lib/jquery-1.11.2.min.js"></script>
    <script src="/static/js/lib/bootstrap.min.js"></script>
    {% block javascript %}
    {% endblock javascript %}
  </body>
</html>
