/* Fonts
==================== */

@font-face {
    font-family: 'ClearSans';
    src: url('../fonts/ClearSans-Regular.eot');
    src: url('../fonts/ClearSans-Regular.eot?#iefix') format('embedded-opentype'),
         url('../fonts/ClearSans-Regular.woff') format('woff'),
         url('../fonts/ClearSans-Regular.ttf') format('truetype'),
         url('../fonts/ClearSans-Regular.svg#open_sans') format('svg');
    font-weight: normal;
    font-style: normal;

}

@font-face {
    font-family: 'ClearSans';
    src: url('../fonts/ClearSans-Bold.eot');
    src: url('../fonts/ClearSans-Bold.eot?#iefix') format('embedded-opentype'),
         url('../fonts/ClearSans-Bold.woff') format('woff'),
         url('../fonts/ClearSans-Bold.ttf') format('truetype'),
         url('../fonts/ClearSans-Bold.svg#open_sansbold') format('svg');
    font-weight: bold;
    font-style: normal;

}

@font-face {
    font-family: 'ClearSans';
    src: url('../fonts/ClearSans-BoldItalic.eot');
    src: url('../fonts/ClearSans-BoldItalic.eot?#iefix') format('embedded-opentype'),
         url('../fonts/ClearSans-BoldItalic.woff') format('woff'),
         url('../fonts/ClearSans-BoldItalic.ttf') format('truetype'),
         url('../fonts/ClearSans-BoldItalic.svg#open_sansbold_italic') format('svg');
    font-weight: bold;
    font-style: italic;

}

@font-face {
    font-family: 'ClearSans';
    src: url('../fonts/ClearSans-Italic.eot');
    src: url('../fonts/ClearSans-Italic.eot?#iefix') format('embedded-opentype'),
         url('../fonts/ClearSans-Italic.woff') format('woff'),
         url('../fonts/ClearSans-Italic.ttf') format('truetype'),
         url('../fonts/ClearSans-Italic.svg#open_sansitalic') format('svg');
    font-weight: normal;
    font-style: italic;

}


/* Generic
==================== */

html,
body {
    height: 100%;
}

body {
    font-size: 16px;
    line-height: 1.4;
    font-family:'ClearSans';
    background-color: #eee;
}

.container {
    max-width: 800px;
}

a {
    color: #f06;
}

blockquote {
    border-left: 5px solid lightgray;
}

.twitter-tweet-rendered {
    margin: auto;
}

img.txt {
    float: left;
    padding: 10px 10px 10px 0px;
    display: block;
}

.post img {
    display: block;
    margin: auto;
    max-width: 90%;
}

#wrapper {
    height: auto;
    min-height: 100%;
    margin-bottom: -60px;
    padding-bottom: 80px;
}


#footer {
    font-size: 0.8em;
    background: #E6E6E6 none repeat scroll 0% 0%;
    border-top: 1px solid #DDD;
    height: 60px;
    text-align: center;
    padding: 20px 0px;
}

a:hover,
a:active,
a:visited {
    color: #f06;
    text-decoration: underline;
}

a.text-muted {
    color: #555;
}

.avatar {
    margin: auto;
    max-width: 120px;
    margin-top: 20px;
}

.home-bio {
    text-align: center;
    margin-top: 10px;
}

.lead {
    padding-left: 10px;
    margin-bottom: 10px;
}

.post-title {
    margin-top: -10px;
    margin-bottom: 20px;
}
